==> dnacentersdk-2.10.0.tar.gz: dnacentersdk-2.10.0/dnacentersdk/models/validators/v2_3_7_9/jsd_d2ece28b509b8ef80b2b8c5c5f36.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center CreateGlobalCredentialsV2 data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorD2EcE28B509B8Ef80B2B8C5C5F36(object):
    """CreateGlobalCredentialsV2 request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorD2EcE28B509B8Ef80B2B8C5C5F36, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "cliCredential": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "enablePassword": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "httpsRead": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "port": {
                "type": "integer"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "httpsWrite": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "port": {
                "type": "integer"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV2cRead": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "readCommunity": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV2cWrite": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "writeCommunity": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV3": {
                "items": {
                "properties": {
                "authPassword": {
                "type": "string"
                },
                "authType": {
                "type": "string"
                },
                "description":
                 {
                "type": "string"
                },
                "privacyPassword": {
                "type": "string"
                },
                "privacyType": {
                "type": "string"
                },
                "snmpMode": {
                "type": "string"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> dnacentersdk-2.10.1.tar.gz: dnacentersdk-2.10.1/dnacentersdk/models/validators/v2_3_5_3/jsd_d2ece28b509b8ef80b2b8c5c5f36.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center CreateGlobalCredentialsV2 data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorD2EcE28B509B8Ef80B2B8C5C5F36(object):
    """CreateGlobalCredentialsV2 request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorD2EcE28B509B8Ef80B2B8C5C5F36, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "cliCredential": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "enablePassword": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "httpsRead": {
                "items": {
                "properties": {
                "name": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "port": {
                "type": "integer"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "httpsWrite": {
                "items": {
                "properties": {
                "name": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "port": {
                "type": "integer"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV2cRead": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "readCommunity": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV2cWrite": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "writeCommunity": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV3": {
                "items": {
                "properties": {
                "authPassword": {
                "type": "string"
                },
                "authType": {
                "type": "string"
                },
                "description":
                 {
                "type": "string"
                },
                "privacyPassword": {
                "type": "string"
                },
                "privacyType": {
                "type": "string"
                },
                "snmpMode": {
                "type": "string"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )
